@@ -1,4 +1,4 @@
-# Hacked up slashdot headlines plugin...
+# Hacked up digg headlines plugin...
 
 require 'time'
 require 'rexml/document'
@@ -13,7 +13,7 @@ class DiggPlugin < Plugin
   def digg(m, params)
     max = params[:limit].to_i
     debug "max is #{max}"
-    xml = @bot.httputil.get(URI.parse("http://digg.com/rss/index.xml"))
+    xml = @bot.httputil.get('http://digg.com/rss/index.xml')
     unless xml
       m.reply "digg news parse failed"
       return
