@@ -1,11 +1,32 @@
+#-- vim:sw=2:et
+#++
+#
+# :title: Berkeley DB interface
+
 begin
   require 'bdb'
+rescue LoadError
+  fatal "rbot couldn't load the bdb module, perhaps you need to install it? try: http://www.ruby-lang.org/en/raa-list.rhtml?name=bdb"
 rescue Exception => e
-  error "Got exception: "+e
-  error "rbot couldn't load the bdb module, perhaps you need to install it? try: http://www.ruby-lang.org/en/raa-list.rhtml?name=bdb"
+  fatal "rbot couldn't load the bdb module: #{e.pretty_inspect}"
+end
+
+if not defined? BDB
   exit 2
 end
 
+if BDB::VERSION_MAJOR < 4
+  fatal "Your bdb (Berkeley DB) version #{BDB::VERSION} is too old!"
+  fatal "rbot will only run with bdb version 4 or higher, please upgrade."
+  fatal "For maximum reliability, upgrade to version 4.2 or higher."
+  raise BDB::Fatal, BDB::VERSION + " is too old"
+end
+
+if BDB::VERSION_MAJOR == 4 and BDB::VERSION_MINOR < 2
+  warning "Your bdb (Berkeley DB) version #{BDB::VERSION} may not be reliable."
+  warning "If possible, try upgrade version 4.2 or later."
+end
+
 # make BTree lookups case insensitive
 module BDB
   class CIBtree < Btree
@@ -80,7 +101,7 @@ module Irc
           @@env = BDB::Env.open("#{@bot.botclass}", BDB::INIT_TRANSACTION | BDB::CREATE | BDB::RECOVER, "set_lg_max" => @@lg_max)
           debug "DBTree: environment opened with max log size #{@@env.conf['lg_max']}"
         rescue => e
-          debug "DBTree: failed to open environment: #{e}. Retrying ..."
+          debug "DBTree: failed to open environment: #{e.pretty_inspect}. Retrying ..."
           @@env = BDB::Env.open("#{@bot.botclass}", BDB::INIT_TRANSACTION | BDB::CREATE |  BDB::RECOVER)
         end
         #@@env = BDB::Env.open("#{@bot.botclass}", BDB::CREATE | BDB::INIT_MPOOL | BDB::RECOVER)
@@ -119,8 +140,8 @@ module Irc
       begin
         debug "DBTree: checkpointing ..."
         @@env.checkpoint
-      rescue => e
-        debug "Failed: #{e}"
+      rescue Exception => e
+        debug "Failed: #{e.pretty_inspect}"
       end
       begin
         debug "DBTree: flushing log ..."
@@ -130,8 +151,8 @@ module Irc
         logs.each { |log|
           File.delete(log)
         }
-      rescue => e
-        debug "Failed: #{e}"
+      rescue Exception => e
+        debug "Failed: #{e.pretty_inspect}"
       end
     end
 
@@ -168,8 +189,8 @@ module Irc
           debug "DBTree: cleaning up environment in #{path}"
           BDB::Env.remove("#{path}")
         end
-      rescue => e
-        error "failed to clean up environment: #{e.inspect}"
+      rescue Exception => e
+        error "failed to clean up environment: #{e.pretty_inspect}"
       end
     end
 
